@@ -1,6 +1,6 @@
 package Test::Class::Moose;
-$Test::Class::Moose::VERSION = '0.53';
-# ABSTRACT: Test::Class + Moose
+$Test::Class::Moose::VERSION = '0.54';
+# ABSTRACT: Serious testing for serious Perl
 
 use 5.10.0;
 use Moose 2.0000;
@@ -488,11 +488,11 @@ __PACKAGE__->meta->make_immutable;
 
 =head1 NAME
 
-Test::Class::Moose - Test::Class + Moose
+Test::Class::Moose - Serious testing for serious Perl
 
 =head1 VERSION
 
-version 0.53
+version 0.54
 
 =head1 SYNOPSIS
 
@@ -519,11 +519,32 @@ version 0.53
 
 =head1 DESCRIPTION
 
-This is B<BETA> code. I encourage you to give it a shot if you want test
-classes based on Moose, along with reporting. Feedback welcome as we try to
-improve it.
+See L<Test::Class::Moose hompage|http://ovid.github.io/test-class-moose/> for
+a summary.
+
+`Test::Class::Moose` is a powerful testing framework for Perl. Out of the box
+you get:
+
+=over 4
+
+=item * Reporting
+
+=item * Extensibility
+
+=item * Tagging tests
+
+=item * Parallel testing
+
+=item * Test inheritance
+
+=item * Write your tests using Moose
+
+=item * All the testing functions and behavior from Test::Most
+
+=item * Event handlers for startup, setup, teardown, and shutdown of test classes
+
+=back
 
-This is a proof of concept for writing Test::Class-style tests with Moose.
 Better docs will come later. You should already know how to use Moose and
 L<Test::Class>.
 
